@@ -12,7 +12,7 @@ WITH RECURSIVE
     ordered_roots AS (SELECT sg.primary_key,
                              sg.position,
                              'segment_group' AS type,
-                             sg.id   AS root_id_text,
+                             sg.id           AS root_id_text,
                              sg.name,
                              sg.ahb_status,
                              sg.anwendungsfall_primary_key,
@@ -23,7 +23,7 @@ WITH RECURSIVE
                              ah.gueltig_von,
                              ah.gueltig_bis,
                              af.beschreibung,
-                             af.kommunikation_von,
+                             af.kommunikationsrichtungen,
                              ah.edifact_format_version,
                              af.anwendungshandbuch_primary_key,
                              null            as is_on_uebertragungsdatei_level
@@ -47,7 +47,7 @@ WITH RECURSIVE
                              ah.gueltig_von,
                              ah.gueltig_bis,
                              af.beschreibung,
-                             af.kommunikation_von,
+                             af.kommunikationsrichtungen,
                              ah.edifact_format_version,
                              af.anwendungshandbuch_primary_key,
                              s.is_on_uebertragungsdatei_level as is_on_uebertragungsdatei_level
@@ -82,7 +82,7 @@ WITH RECURSIVE
                               o.gueltig_von,
                               o.gueltig_bis,
                               o.beschreibung,
-                              o.kommunikation_von,
+                              o.kommunikationsrichtungen,
                               o.edifact_format_version,
                               o.anwendungshandbuch_primary_key,
                               o.is_on_uebertragungsdatei_level,
@@ -141,7 +141,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          h.is_on_uebertragungsdatei_level,
@@ -199,7 +199,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          s.is_on_uebertragungsdatei_level,
@@ -255,7 +255,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          h.is_on_uebertragungsdatei_level,
@@ -311,7 +311,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          h.is_on_uebertragungsdatei_level,
@@ -368,7 +368,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          h.is_on_uebertragungsdatei_level,
@@ -424,7 +424,7 @@ WITH RECURSIVE
                          h.gueltig_von,
                          h.gueltig_bis,
                          h.beschreibung,
-                         h.kommunikation_von,
+                         h.kommunikationsrichtungen,
                          h.edifact_format_version,
                          h.anwendungshandbuch_primary_key,
                          h.is_on_uebertragungsdatei_level,
@@ -459,7 +459,26 @@ WITH RECURSIVE
                            JOIN code c ON c.data_element_primary_key = h.current_id
                   WHERE h.type = 'dataelement')
 
-SELECT hex(randomblob(16)) AS id, *
+SELECT hex(randomblob(16)) AS id,
+       *,
+       -- add 2 computed columns which are used in v_ahbtabellen only but not indexable if they were not real columns (but just an expression inside a view definition)
+       trim(
+               coalesce(
+                       code_name,
+                       dataelement_name,
+                       dataelementgroup_name,
+                       segment_name,
+                       segmentgroup_name
+               )
+       )                   as line_name,
+       trim(
+               coalesce(
+                       code_ahb_status,
+                       dataelement_ahb_status,
+                       segment_ahb_status,
+                       segmentgroup_ahb_status
+               )
+       )                   as line_ahb_status
 FROM hierarchy
 ORDER BY anwendungsfall_pk, sort_path;
 
@@ -467,20 +486,24 @@ ORDER BY anwendungsfall_pk, sort_path;
 
 CREATE UNIQUE INDEX idx_hierarchy_id ON ahb_hierarchy_materialized (id);
 CREATE INDEX idx_hierarchy_afpk ON ahb_hierarchy_materialized (anwendungsfall_pk);
-CREATE INDEX idx_hierarchy_sort ON ahb_hierarchy_materialized (anwendungsfall_pk, sort_path);
+CREATE INDEX idx_hierarchy_awfpk_sort ON ahb_hierarchy_materialized (anwendungsfall_pk, sort_path);
 CREATE INDEX idx_hierarchy_type ON ahb_hierarchy_materialized (type);
 CREATE INDEX idx_hierarchy_pruefidentifikator ON ahb_hierarchy_materialized (pruefidentifikator);
 CREATE INDEX idx_hierarchy_format ON ahb_hierarchy_materialized (format);
+CREATE INDEX idx_hierarchy_format_format_version ON ahb_hierarchy_materialized (format, edifact_format_version);
 CREATE INDEX idx_hierarchy_versionsnummer ON ahb_hierarchy_materialized (versionsnummer);
 CREATE INDEX idx_hierarchy_gueltig_von ON ahb_hierarchy_materialized (gueltig_von);
 CREATE INDEX idx_hierarchy_gueltig_bis ON ahb_hierarchy_materialized (gueltig_bis);
 CREATE INDEX idx_hierarchy_beschreibung ON ahb_hierarchy_materialized (beschreibung);
-CREATE INDEX idx_hierarchy_kommunikation_von ON ahb_hierarchy_materialized (kommunikation_von);
+CREATE INDEX idx_hierarchy_beschreibung_lower ON ahb_hierarchy_materialized (lower(beschreibung));
+CREATE INDEX idx_hierarchy_kommunikationsrichtungen ON ahb_hierarchy_materialized (kommunikationsrichtungen);
 CREATE INDEX idx_hierarchy_edifact_format_version ON ahb_hierarchy_materialized (edifact_format_version);
 CREATE INDEX idx_hierarchy_segmentgroup_id ON ahb_hierarchy_materialized (segmentgroup_id);
+CREATE INDEX idx_hierarchy_segmentgroup_id_lower ON ahb_hierarchy_materialized (lower(segmentgroup_id));
 CREATE INDEX idx_hierarchy_segmentgroup_name ON ahb_hierarchy_materialized (segmentgroup_name);
 CREATE INDEX idx_hierarchy_segmentgroup_position ON ahb_hierarchy_materialized (segmentgroup_position);
 CREATE INDEX idx_hierarchy_segment_id ON ahb_hierarchy_materialized (segment_id);
+CREATE INDEX idx_hierarchy_segment_id_lower ON ahb_hierarchy_materialized (lower(segment_id));
 CREATE INDEX idx_hierarchy_segment_name ON ahb_hierarchy_materialized (segment_name);
 CREATE INDEX idx_hierarchy_segment_number ON ahb_hierarchy_materialized (segment_number);
 CREATE INDEX idx_hierarchy_segment_position ON ahb_hierarchy_materialized (segment_position);
@@ -488,18 +511,50 @@ CREATE INDEX idx_hierarchy_dataelementgroup_id ON ahb_hierarchy_materialized (da
 CREATE INDEX idx_hierarchy_dataelementgroup_name ON ahb_hierarchy_materialized (dataelementgroup_name);
 CREATE INDEX idx_hierarchy_dataelementgroup_position ON ahb_hierarchy_materialized (dataelementgroup_position);
 CREATE INDEX idx_hierarchy_dataelement_id ON ahb_hierarchy_materialized (dataelement_id);
+CREATE INDEX idx_hierarchy_dataelement_id_lower ON ahb_hierarchy_materialized (lower(dataelement_id));
 CREATE INDEX idx_hierarchy_dataelement_name ON ahb_hierarchy_materialized (dataelement_name);
 CREATE INDEX idx_hierarchy_dataelement_position ON ahb_hierarchy_materialized (dataelement_position);
 CREATE INDEX idx_hierarchy_dataelement_ahb_status ON ahb_hierarchy_materialized (dataelement_ahb_status);
 CREATE INDEX idx_hierarchy_code_id ON ahb_hierarchy_materialized (code_id);
 CREATE INDEX idx_hierarchy_code_name ON ahb_hierarchy_materialized (code_name);
 CREATE INDEX idx_hierarchy_code_description ON ahb_hierarchy_materialized (code_description);
+CREATE INDEX idx_hierarchy_code_description_lower ON ahb_hierarchy_materialized (lower(code_description));
 CREATE INDEX idx_hierarchy_code_value ON ahb_hierarchy_materialized (code_value);
+CREATE INDEX idx_hierarchy_code_value_lower ON ahb_hierarchy_materialized (lower(code_value));
 CREATE INDEX idx_hierarchy_code_ahb_status ON ahb_hierarchy_materialized (code_ahb_status);
 CREATE INDEX idx_hierarchy_code_position ON ahb_hierarchy_materialized (code_position);
 CREATE INDEX idx_hierarchy_path ON ahb_hierarchy_materialized (path);
 CREATE INDEX idx_hierarchy_id_path ON ahb_hierarchy_materialized (id_path);
+CREATE INDEX idx_hierarchy_sort ON ahb_hierarchy_materialized (sort_path);
+
+-- the following 2 indexes are to speed of v_ahbtabellen only
+CREATE INDEX idx_ahb_tabellen_filter1 ON ahb_hierarchy_materialized (dataelement_ahb_status) WHERE type = 'dataelement' AND dataelement_ahb_status IS NOT NULL;
+CREATE INDEX idx_ahb_tabellen_filter2 ON ahb_hierarchy_materialized (type) WHERE type <> 'dataelementgroup';
+
+-- indexes for computed columns for v_ahbtabellen
+CREATE INDEX idx_line_ahb_status ON ahb_hierarchy_materialized (line_ahb_status);
+CREATE INDEX idx_line_ahb_status_lower ON ahb_hierarchy_materialized (lower(line_ahb_status));
+CREATE INDEX idx_line_name ON ahb_hierarchy_materialized (line_name);
+CREATE INDEX idx_line_name_lower ON ahb_hierarchy_materialized (lower(line_name));
+CREATE INDEX idx_hierarchy_sort_path_per_ahb ON ahb_hierarchy_materialized (sort_path, pruefidentifikator, edifact_format_version);
+
+-- Append position to id_path only where duplicates exist (to ensure uniqueness while keeping paths clean)
+-- This updates id_paths that are not unique per (pruefidentifikator, edifact_format_version) by appending the sort_path
+UPDATE ahb_hierarchy_materialized
+SET id_path = id_path || '@' || sort_path
+WHERE id IN (SELECT h1.id
+             FROM ahb_hierarchy_materialized h1
+             WHERE EXISTS (SELECT 1
+                           FROM ahb_hierarchy_materialized h2
+                           WHERE h2.id_path = h1.id_path
+                             AND h2.pruefidentifikator = h1.pruefidentifikator
+                             AND (h2.edifact_format_version = h1.edifact_format_version OR
+                                  (h2.edifact_format_version IS NULL AND h1.edifact_format_version IS NULL))
+                             AND h2.id != h1.id));
+
 -- if the unique part of the following indexes raises an integrity error, this is handled by the calling python code
-CREATE UNIQUE INDEX idx_hierarchy_path_per_ahb ON ahb_hierarchy_materialized (path, pruefidentifikator, edifact_format_version);
-CREATE UNIQUE INDEX idx_hierarchy_id_path_per_ahb ON ahb_hierarchy_materialized (id_path, pruefidentifikator, edifact_format_version);
+-- column order optimized for v_ahb_diff queries: filter by (version, pruefi) first, then lookup by id_path/path
+CREATE UNIQUE INDEX idx_hierarchy_id_path_per_ahb ON ahb_hierarchy_materialized (edifact_format_version, pruefidentifikator, id_path);
+
+CREATE UNIQUE INDEX idx_hierarchy_path_per_ahb ON ahb_hierarchy_materialized (edifact_format_version, pruefidentifikator, path);
 
