@@ -53,6 +53,31 @@ def strip(prefix: str, text: str, suffix: str) -> str:
     return lstrip(prefix, rstrip(text, suffix))
 
 
+_replacements: dict[str, str] = {
+    "-\r\n": "",
+    "\r\n": " ",
+    "\r": "",
+    "\n": "",
+}
+
+
+def remove_linebreaks_and_hyphens(original: str) -> str:
+    """
+    Normalize a multi line string by stripping leading and trailing whitespace and removing line breaks.
+
+    Args:
+        original: The string to normalize.
+
+    Returns:
+        The normalized string.
+    """
+    result = original
+    for old, new in _replacements.items():
+        result = result.replace(old, new)
+    # if you add more replacement rules, please also add a unit test in test_utils.py
+    return " ".join(result.strip().split())
+
+
 _UNIFIED_SEPARATOR = "/"  # how multiple Marktrollen shall be split in the kommunikation_von attribute
 _ALTERNATIVE_SEPARATORS = [","]  # other separators that are used in the wild
 
@@ -118,4 +143,4 @@ def parse_kommunikation_von(kommunikation_von: Optional[str]) -> list[Kommunikat
     return result
 
 
-__all__ = ["lstrip", "rstrip", "strip", "parse_kommunikation_von"]
+__all__ = ["lstrip", "rstrip", "strip", "parse_kommunikation_von", "remove_linebreaks_and_hyphens"]
